@@ -1,18 +1,15 @@
 package presentation
 
 import (
+	"github.com/jesseduffield/generics/slices"
 	"github.com/jesseduffield/lazygit/pkg/commands/models"
 	"github.com/jesseduffield/lazygit/pkg/theme"
 )
 
 func GetSubmoduleListDisplayStrings(submodules []*models.SubmoduleConfig) [][]string {
-	lines := make([][]string, len(submodules))
-
-	for i := range submodules {
-		lines[i] = getSubmoduleDisplayStrings(submodules[i])
-	}
-
-	return lines
+	return slices.Map(submodules, func(submodule *models.SubmoduleConfig) []string {
+		return getSubmoduleDisplayStrings(submodule)
+	})
 }
 
 func getSubmoduleDisplayStrings(s *models.SubmoduleConfig) []string {
