@@ -182,7 +182,7 @@ func koreanTranslationSet() TranslationSet {
 		RecentRepos:                         "최근에 사용한 저장소",
 		MergeOptionsTitle:                   "Merge options",
 		RebaseOptionsTitle:                  "Rebase options",
-		CommitMessageTitle:                  "커밋메시지",
+		CommitSummaryTitle:                  "커밋메시지",
 		LocalBranchesTitle:                  "브랜치",
 		SearchTitle:                         "검색",
 		TagsTitle:                           "태그",
@@ -310,8 +310,8 @@ func koreanTranslationSet() TranslationSet {
 		EditRemote:                 "Remote를 수정",
 		TagCommit:                  "Tag commit",
 		TagMenuTitle:               "태그 작성",
-		TagNameTitle:               "태그 이름:",
-		TagMessageTitle:            "태그 메시지: ",
+		TagNameTitle:               "태그 이름",
+		TagMessageTitle:            "태그 메시지",
 		AnnotatedTag:               "Annotated tag",
 		LightweightTag:             "Lightweight tag",
 		DeleteTag:                  "태그 삭제",
@@ -320,7 +320,6 @@ func koreanTranslationSet() TranslationSet {
 		PushTagTitle:               "원격에 태그 '{{.tagName}}' 를 푸시",
 		PushTag:                    "태그를 push",
 		CreateTag:                  "태그를 생성",
-		CreateTagTitle:             "태그 이름:",
 		FetchRemote:                "원격을 업데이트",
 		FetchingRemoteStatus:       "원격을 업데이트 중",
 		CheckoutCommit:             "커밋을 체크아웃",
