@@ -216,7 +216,7 @@ func RussianTranslationSet() TranslationSet {
 		RecentRepos:                         "Последние репозитории",
 		MergeOptionsTitle:                   "Параметры слияния",
 		RebaseOptionsTitle:                  "Параметры перебазирования",
-		CommitMessageTitle:                  "Сводка коммита",
+		CommitSummaryTitle:                  "Сводка коммита",
 		CommitDescriptionTitle:              "Описание коммита",
 		CommitDescriptionSubTitle:           "Нажмите вкладку, чтобы переключить фокус",
 		LocalBranchesTitle:                  "Локальные Ветки",
@@ -371,8 +371,8 @@ func RussianTranslationSet() TranslationSet {
 		EditRemote:                          "Редактировать удалённый репозитории",
 		TagCommit:                           "Пометить коммит тегом",
 		TagMenuTitle:                        "Создать тег",
-		TagNameTitle:                        "Название тега:",
-		TagMessageTitle:                     "Сообщения тега:",
+		TagNameTitle:                        "Название тега",
+		TagMessageTitle:                     "Сообщения тега",
 		AnnotatedTag:                        "Аннотированный тег",
 		LightweightTag:                      "Легковесный тег",
 		DeleteTag:                           "Удалить тег",
@@ -381,7 +381,6 @@ func RussianTranslationSet() TranslationSet {
 		PushTagTitle:                        "Удалённый репозитории для отправки тега '{{.tagName}}' в:",
 		PushTag:                             "Отправить тег",
 		CreateTag:                           "Создать тег",
-		CreateTagTitle:                      "Название тега:",
 		FetchRemote:                         "Получение изменения из удалённого репозитория",
 		FetchingRemoteStatus:                "Получение статуса удалённого репозитория",
 		CheckoutCommit:                      "Переключить коммит",
