@@ -7,8 +7,11 @@ import (
 )
 
 var (
+	// DefaultTextColor is the default text color
+	DefaultTextColor = style.FgDefault
+
 	// GocuiDefaultTextColor does the same as DefaultTextColor but this one only colors gocui default text colors
-	GocuiDefaultTextColor gocui.Attribute
+	GocuiDefaultTextColor = gocui.ColorDefault
 
 	// ActiveBorderColor is the border color of the active frame
 	ActiveBorderColor gocui.Attribute
@@ -16,14 +19,14 @@ var (
 	// InactiveBorderColor is the border color of the inactive active frames
 	InactiveBorderColor gocui.Attribute
 
+	// FilteredActiveBorderColor is the border color of the active frame, when it's being searched/filtered
+	SearchingActiveBorderColor gocui.Attribute
+
 	// GocuiSelectedLineBgColor is the background color for the selected line in gocui
 	GocuiSelectedLineBgColor gocui.Attribute
 
 	OptionsColor gocui.Attribute
 
-	// DefaultTextColor is the default text color
-	DefaultTextColor = style.FgWhite
-
 	// SelectedLineBgColor is the background color for the selected line
 	SelectedLineBgColor = style.New()
 
@@ -44,6 +47,7 @@ var (
 func UpdateTheme(themeConfig config.ThemeConfig) {
 	ActiveBorderColor = GetGocuiStyle(themeConfig.ActiveBorderColor)
 	InactiveBorderColor = GetGocuiStyle(themeConfig.InactiveBorderColor)
+	SearchingActiveBorderColor = GetGocuiStyle(themeConfig.SearchingActiveBorderColor)
 	SelectedLineBgColor = GetTextStyle(themeConfig.SelectedLineBgColor, true)
 	SelectedRangeBgColor = GetTextStyle(themeConfig.SelectedRangeBgColor, true)
 
