@@ -6,10 +6,13 @@ import (
 
 	"github.com/gookit/color"
 	"github.com/jesseduffield/lazygit/pkg/gui/style"
+	"github.com/samber/lo"
 )
 
-var decoloriseCache = make(map[string]string)
-var decoloriseMutex sync.RWMutex
+var (
+	decoloriseCache = make(map[string]string)
+	decoloriseMutex sync.RWMutex
+)
 
 // Decolorise strips a string of color
 func Decolorise(str string) string {
@@ -53,10 +56,10 @@ func IsValidHexValue(v string) bool {
 }
 
 func SetCustomColors(customColors map[string]string) map[string]style.TextStyle {
-	colors := make(map[string]style.TextStyle)
-	for key, colorSequence := range customColors {
-		style := style.New().SetFg(style.NewRGBColor(color.HEX(colorSequence, false)))
-		colors[key] = style
-	}
-	return colors
+	return lo.MapValues(customColors, func(c string, key string) style.TextStyle {
+		if s, ok := style.ColorMap[c]; ok {
+			return s.Foreground
+		}
+		return style.New().SetFg(style.NewRGBColor(color.HEX(c, false)))
+	})
 }
